# Mediabyte Documentation

<br>

[**Basic Mixtape Operations**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20Basic%20Mixtape%20operations.ipynb) - Learn how to build a Mixtape from a few Samples and basic Mixtape handling

[**Playback**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20Playback.ipynb) - What are the playback and output options

[**Mixtape from .omm file**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20Mixtape%20from%20omm%20file.ipynb) - How to use the Mixtape file format

[**Mixtape Arbitrary White-Space**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20Mixtape%20Arbitrary%20White-Space.ipynb) - Learn how to use Mixtape file freestyle formatting

[**Mp3 Mixtape Cutting**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20bit.Mp3%20Mixtape%20Cutting.ipynb) - How to cut and remix MP3 Mixtape

[**Mediabyte Hash Referencing**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20Mediabyte%20Hash%20Referencing.ipynb) - Using the system-wide o.hash for general referencing

[**One-line YouTube search to VLC playback**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20One-line%20YouTube%20search%20to%20VLC%20playback.ipynb) - Succinct common use-case

[**Online .omm support**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20Online%20.omm%20support.ipynb) - How to load an online .omm Mixtape

[**Cue Shifting**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20Cue%20shifting.ipynb) - Learn how to time-shift a Cue

[**Sample skipping, extending and splitting**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20Sample%20skipping%2C%20extending%20and%20splitting.ipynb) - Sample editing features

[**Subtitle Search**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20Subtitle%20Search.ipynb) - Learn how to do a srt-based keyword search

[**YouTube URL input**](https://github.com/taext/mediabyte/blob/master/user_guide/Demo:%20YouTube%20URL%20input.ipynb) - YouTube URL support
